## Abstract Base Class

::: prob_conf_mat.metrics.abc.Metric
    options:
        heading_level: 3

::: prob_conf_mat.metrics.abc.AveragedMetric
    options:
        heading_level: 3

## Metric Instances

::: prob_conf_mat.metrics._metrics.DiagMass
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.Prevalence
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.ModelBias
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.TruePositiveRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.FalseNegativeRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.PositivePredictiveValue
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.FalseDiscoveryRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.FalsePositiveRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.TrueNegativeRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.FalseOmissionRate
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.NegativePredictiveValue
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.Accuracy
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.BalancedAccuracy
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.MatthewsCorrelationCoefficient
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.CohensKappa
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.F1
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.FBeta
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.Informedness
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.Markedness
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.P4
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.JaccardIndex
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.PositiveLikelihoodRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.LogPositiveLikelihoodRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.NegativeLikelihoodRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.LogNegativeLikelihoodRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.DiagnosticOddsRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.LogDiagnosticOddsRatio
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics._metrics.PrevalenceThreshold
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - bounds
                - dependencies
                - is_multiclass
                - sklearn_equivalent
        show_labels: false
        group_by_category: false
